Module accelerate

Module accelerate 

Structs

AcceleratorIter
An iterator over the variants of Accelerator

Enums

Accelerator
A hardware accelerator that can be used to compute any target metrics.

Functions

get_default_accelerators
Returns the enabled, default accelerators, in order of what to attempt.