Accelerator

Enum Accelerator 

pub enum Accelerator {
    Cuda,
    Rocm,
    Vulkan,
    Metal,
    Cpu,
}
A hardware accelerator that can be used to compute any target metrics.

Variants



Cuda

Available on crate feature cuda only.

Run kernels using the Nvidia CUDA backend.

Nvidia GPUs only (duh.)



Rocm

Available on crate feature rocm only.

Run kernels using the AMD ROCm backend.

AMD GPUs only (duh.)



Vulkan

Available on crate feature vulkan only.

Run kernels using the WGPU Vulkan backend.

This is the most lightweight and portable accelerator because it supports all platforms and GPUs that support basic compute shaders.



Metal

Available on crate feature metal only.

Run kernels using the WGPU Metal backend.

This is the only accelerator available for Apple Silicon.



Cpu

Available on crate feature cpu only.

Run kernels using the CPU JIT compiler.