apply_compilation_cache_env

Function apply_compilation_cache_env 

pub fn apply_compilation_cache_env() -> Result<Option<PathBuf>, CacheAlreadyInitialisedError>
Apply the AV_DENOISE_COMPILATION_CACHE override if set.

Returns Ok(Some(path)) if the override was installed, Ok(None) if the env var was unset, or Err if the global config was already read by something else (e.g. a previously-created CubeCL client).

Must be called before any CubeCL client is created.