pub struct FrameLayout {
pub width: u32,
pub height: u32,
pub subsampling: Subsampling,
pub depth: Depth,
}Fields
width: u32height: u32subsampling: Subsamplingdepth: DepthImplementations
Sourceimpl FrameLayout
impl FrameLayout
pub fn luma_pixels(&self) -> usize
pub fn chroma_dims(&self) -> (u32, u32)
pub fn chroma_pixels(&self) -> usize
Sourcepub fn luma_bytes(&self) -> usize
pub fn luma_bytes(&self) -> usize
Wire size of the luma plane.
Sourcepub fn chroma_bytes(&self) -> usize
pub fn chroma_bytes(&self) -> usize
Wire size of one chroma plane.
Sourcepub fn black_luma_plane(&self) -> Vec<u8> ⓘ
pub fn black_luma_plane(&self) -> Vec<u8> ⓘ
A full black luma plane, used when no luma source is available.
Sourcepub fn neutral_chroma_plane(&self) -> Vec<u8> ⓘ
pub fn neutral_chroma_plane(&self) -> Vec<u8> ⓘ
A full neutral chroma plane, used when a source has no chroma.