Structs
- Accelerator
Iter - An iterator over the variants of Accelerator
Enums
- Accelerator
- A hardware accelerator that can be used to compute any target metrics.
Functions
- get_
default_ accelerators - Returns the enabled, default accelerators, in order of what to attempt.